class Transporters:
    BRIEFPOST = "BRIEFPOST"
    UPS = "UPS"
    POSTNL = "TNT"
    POSTNL_EXTRA = "TNT-EXTRA"
    POSTNL_BRIEFPOST = "TNT_BRIEF"
    TNT_EXPRESS = "TNT-EXPRESS"
    DYNALOGIC = "DYL"
    DPD_NL = "DPD-NL"
    DPD_BE = "DPD-BE"
    BPOST_BE = "BPOST_BE"
    BPOST_BRIEFPOST = "BPOST_BRIEF"
    DHLFORYOU = "DHLFORYOU"
    GLS = "GLS"
    FEDEX_NL = "FEDEX_NL"
    FEDEX_BE = "FEDEX_BE"
    OTHER = "OTHER"
    DHL = "DHL"
    DHL_DE = "DHL_DE"
    DHL_GLOBAL_MAIL = "DHL-GLOBAL-MAIL"
    TRANSPORTSERVICE_NL = "TSN"
    FIEGE = "FIEGE"
    TRANSMISSION = "TRANSMISSION"
    PARCEL_NL = "PARCEL-NL"
    LOGOIX = "LOGOIX"
    PACKS = "PACKS"
    COURIER = "COURIER"
    NEDWRK = "RJP"